@@ -1,6 +1,6 @@
 /* Scheme interface to stack frames.
 
-   Copyright (C) 2008-2023 Free Software Foundation, Inc.
+   Copyright (C) 2008-2026 Free Software Foundation, Inc.
 
    This file is part of GDB.
 
@@ -20,7 +20,6 @@
 /* See README file in this directory for implementation notes, coding
    conventions, et.al.  */
 
-#include "defs.h"
 #include "block.h"
 #include "frame.h"
 #include "inferior.h"
@@ -666,7 +665,7 @@ gdbscm_frame_function (SCM self)
       if (frame != NULL)
 	{
 	  found = true;
-	  sym = find_pc_function (get_frame_address_in_block (frame));
+	  sym = find_symbol_for_pc (get_frame_address_in_block (frame));
 	}
     }
   catch (const gdb_exception &except)
@@ -832,10 +831,10 @@ gdbscm_frame_read_register (SCM self, SCM register_scm)
 	{
 	  found = true;
 	  regnum = user_reg_map_name_to_regnum (get_frame_arch (frame),
-						register_str,
-						strlen (register_str));
+						register_str);
 	  if (regnum >= 0)
-	    value = value_of_register (regnum, frame);
+	    value = value_of_register (regnum,
+				       get_next_frame_sentinel_okay (frame));
 	}
     }
   catch (const gdb_exception &ex)
@@ -936,7 +935,7 @@ gdbscm_frame_read_var (SCM self, SCM symbol_scm, SCM rest)
 
 	    if (block == NULL)
 	      block = get_frame_block (frame_info_ptr (frame), NULL);
-	    lookup_sym = lookup_symbol (var_name.get (), block, VAR_DOMAIN,
+	    lookup_sym = lookup_symbol (var_name.get (), block, SEARCH_VFT,
 					NULL);
 	    var = lookup_sym.symbol;
 	    block = lookup_sym.block;
