@@ -2118,8 +2118,8 @@ yyreduce:
 			      if (msymbol.minsym != NULL)
 				pstate->push_new<var_msym_value_operation>
 				  (msymbol);
-			      else if (!have_full_symbols (current_program_space)
-				       && !have_partial_symbols (current_program_space))
+			      else if (!current_program_space->has_full_symbols ()
+				       && !current_program_space->has_partial_symbols ())
 				error (_("No symbol table is loaded.  "
 				       "Use the \"file\" command."));
 			      else
